@@ -1,35 +1,18 @@
 # !/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from asyncio import iscoroutinefunction
+from copy import deepcopy
 from functools import wraps
-from inspect import signature, stack
+from inspect import signature
 from json import dumps, loads
 from json.decoder import JSONDecodeError
-from re import split as re_split
 from sys import exc_info
+from time import localtime, strftime
 from traceback import extract_tb
 from typing import BinaryIO, Callable, Optional, Union
 
 from .version import __version__
 
-
-def __getattr__(identifier: str) -> object:
-    if re_split(r"[/\\]", stack()[1].filename)[-1] not in (
-        "qg_bot.py",
-        "qg_bot_ws.py",
-        "api.py",
-        "async_api.py",
-        "model.py",
-        "_api_model.py",
-        "http.py",
-        "plugins.py",
-        "<frozen importlib._bootstrap>",
-    ):
-        raise AssertionError("此为SDK内部使用文件，无法使用")
-
-    return globals()[identifier.__path__]
-
-
 general_header = {"User-Agent": f"qg-botsdk v{__version__}"}
 security_header = {
     "Content-Type": "application/json",
@@ -129,21 +112,33 @@ def exception_processor(func):
             if logger:
                 logger.error(e.__repr__())
                 logger.debug(exception_handler(e))
+            else:
+                t = strftime("%m-%d %H:%M:%S", localtime())
+                print(f"\033[1;31m[{t}] [ERROR]\033[0m {e.__repr__()}")
+                print(f"[{t}] [DEBUG] {exception_handler(e)}")
 
     return wrap
 
 
-class object_class(type):
+class object_class(object):
+    def __init__(self, **kwargs):
+        for k, v in kwargs.items():
+            self.__setattr__(k, v)
+
+    def __getattribute__(self, item):
+        if item == "__doc__":
+            return object.__getattribute__(self, "__repr__")()
+        return object.__getattribute__(self, item)
+
     def __repr__(self):
-        return self.__doc__
+        try:
+            return dumps(self._data)
+        except (TypeError, ValueError):
+            return str(self._data)
 
     @property
     def dict(self):
-        try:
-            return_ = loads(self.__doc__)
-        except JSONDecodeError:
-            return_ = {}
-        return return_
+        return self._data
 
 
 def _send_msg():  # Cannot direct import from _api_model.py since circular import
@@ -260,42 +255,38 @@ class async_event_class(object_class):
 
 
 def objectize(
-    data, api=None, is_async=False
+    data, api=None, is_async=False, is_recursion=False
 ):  # if api is no None, the event is a resp class
-    try:
-        doc = dumps(data)
-    except TypeError:
-        doc = str(data)
     if isinstance(data, dict):
+        _data = data
+        if not is_recursion:
+            # create a copy that doesn't reference to the original data
+            data = deepcopy(data)
+        # main func to process data
         for keys, values in data.items():
             if keys.isnumeric():
                 return data
             if isinstance(values, dict):
-                data[keys] = objectize(values)
+                data[keys] = objectize(values, is_recursion=True)
             elif isinstance(values, list):
                 for i, items in enumerate(values):
                     if isinstance(items, dict):
-                        data[keys][i] = objectize(items)
-        data["__doc__"] = doc
+                        data[keys][i] = objectize(items, is_recursion=True)
+        data["_data"] = _data
         if api:
             data["api"] = api
-            object_data = (
-                async_event_class("object", (object,), data)
-                if is_async
-                else event_class("object", (object,), data)
-            )
+            object_data = async_event_class(**data) if is_async else event_class(**data)
         else:
-            object_data = object_class("object", (object,), data)
+            object_data = object_class(**data)
         return object_data
     else:
         return data
 
 
-def treat_msg(raw_msg: str, bot_id: str):
+def treat_msg(raw_msg: str, at: str):
+    raw_msg = raw_msg if raw_msg.find(at) else raw_msg.replace(at, "", 1).strip()
     if not raw_msg:
         return ""
-    at = f"<@!{bot_id}>"
-    raw_msg = raw_msg if raw_msg.find(at) else raw_msg.replace(at, "", 1).strip()
     if raw_msg[0] == "/":
         raw_msg = raw_msg[1:]
     return (
@@ -307,6 +298,16 @@ def treat_msg(raw_msg: str, bot_id: str):
     )
 
 
+def treat_thread(data: dict):
+    for items in ("content", "title"):
+        try:
+            data["d"]["thread_info"][items] = loads(
+                data.get("d", {}).get("thread_info", {}).get(items, "{}")
+            )
+        except JSONDecodeError:
+            pass
+
+
 @template_wrapper
 async def http_temp(return_, code: int):
     trace_id = return_.headers.get("X-Tps-Trace-Id")
